@@ -74,21 +74,26 @@ def download(db: Connection, args: List[str]):
         users: Optional[List[str]] = None
         folders: Optional[List[str]] = None
         if args[1:] and args[1] != "--":
-            users = list(set(map(user_clean_name, args[1].split(","))))
+            users_tmp: List[str] = list(filter(bool, map(user_clean_name, args[1].split(","))))
+            users = sorted(set(users_tmp), key=users_tmp.index)
         if args[2:] and args[2] != "--":
-            folders = list(set(map(str.strip, args[2].split(","))))
+            folders_tmp: List[str] = list(filter(bool, map(str.strip, args[2].split(","))))
+            folders = sorted(set(folders_tmp), key=folders_tmp.index)
         users_update(api, db, users, folders)
     elif args[0] == "users":
         if len(args[1:]) == 2 and args[1] and args[2]:
-            users: List[str] = list(set(map(user_clean_name, args[1].split(","))))
-            folders: List[str] = list(set(map(str.strip, args[2].split(","))))
+            users_tmp: List[str] = list(filter(bool, map(user_clean_name, args[1].split(","))))
+            users: List[str] = sorted(set(users_tmp), key=users_tmp.index)
+            folders_tmp: List[str] = list(filter(bool, map(str.strip, args[2].split(","))))
+            folders: List[str] = sorted(set(folders_tmp), key=folders_tmp.index)
             users_download(api, db, users, folders)
         else:
             raise CommandError("Malformed command: users needs two arguments")
     elif args[0] == "submissions":
         if not args[1:]:
             raise CommandError("Malformed command: submissions needs at least one argument")
-        sub_ids: List[str] = list(set(filter(str.isdigit, args[1:])))
+        sub_ids_tmp: List[str] = list(filter(str.isdigit, args[1:]))
+        sub_ids: List[str] = sorted(set(sub_ids_tmp), key=sub_ids_tmp.index)
         submissions_download(api, db, sub_ids)
     else:
         raise CommandError(f"Unknown download command {args[0]}")
